
$TITLE Trade Liberalization for Stylized Numerical CGE Model
$OFFSYMLIST OFFSYMXREF

*## TRADE LIBERALIZATION IN MFG (high wage sector)
*## When used against the base model generated by EW.GMS
*## the experiment results reproduce those found in table 14.11
*## Thierfelder and Shiells, CH 14: "Trade and Labor Market Behavior" 
*## Contact thier@nadn.navy.mil with questions about GAMS code


TM.FX(i)         = 0.0 ;

OPTION LIMROW    = 5 ;

Solve Trade Using NLP minimizing WELFARE ;


* tables for paper

PARAMETER 
          QUANT(rq,i)     EXPERIMENT OUTPUT QUANTITIES
          PRICE(rp,i)     EXPERIMENT OUTPUT PRICES
          FACTOR(rf,i)    EXPERIMENT FACTOR MARKETS 
          AGG(ra)         EXPERIMENT AGGREGATES
          RQUANT(rq,i)    PERCENT CHANGE IN OUTPUT QUANTITIES
          RPRICE(rp,i)    PERCENT CHANGE IN OUTPUT PRICES
          RFACTOR(rf,i)   PERCENT CHANGE IN FACTOR MARKETS 
          ABAGG(ra)       ABSOLUTE CHANGE IN AGGREGATES
;
QUANT("x",i)   = X.L(i) ;
QUANT("q",i)   = Q.L(i) ;
QUANT("dd",i)  = DD.L(i) ;
QUANT("e",i)   = E.L(i) ;
QUANT("m",i)   = M.L(i) ;

PRICE("px",i)  = PX.L(i) ;
PRICE("pq",i)  = PQ.L(i) ;
PRICE("pdt",i) = PDT.L(i) ;
PRICE("ped",i) = PED.L(i) ;
PRICE("pwe",i) = PWE.L(i) ;
PRICE("pmd",i) = PMD.L(i) ;
PRICE("pwm",i) = PWM.L(i) ;

FACTOR("fd_L",i)      = FDSC.L(i,"lab") ;
FACTOR("fd_K",i)      = FDSC.L(i,"cap") ;
FACTOR("wf_L",i)      = SUM(j, WF.L("lab")*WFDIST.L(j,"lab")*FDSC.L(j,"lab"))/
                        SUM(j, FDSC.L(j,"lab"))  ;
FACTOR("wf_K",i)      = SUM(j, WF.L("cap")*WFDIST.L(j,"cap")*FDSC.L(j,"cap"))/
                        SUM(j, FDSC.L(j,"cap"))  ;
FACTOR("wfdist_L",i)  = WFDIST.L(i,"lab") ;
FACTOR("wfdist_K",i)  = WFDIST.L(i,"cap") ;

AGG("er")   = ER.L ;
AGG("util") = UTIL.L ;
AGG("ev")   = EV.L ;

DISPLAY QUANT, PRICE, FACTOR, AGG ;

RQUANT(rq,i)$QUANT0(rq,i)       = 100*(QUANT(rq,i) - QUANT0(rq,i))/
                                  QUANT0(rq,i) ;
RPRICE(rp,i)$PRICE0(rp,i)       = 100*(PRICE(rp,i) - PRICE0(rp,i))/
                                  PRICE0(rp,i) ;
RFACTOR(rf,i)$FACTOR0(rf,i)     = 100*(FACTOR(rf,i) - FACTOR0(rf,i))/
                                  FACTOR0(rf,i) ;
ABAGG(ra)                       = AGG(ra) - AGG0(ra) ;

DISPLAY RQUANT, RPRICE, RFACTOR, ABAGG ;

FILE RES /TLEW.PRN/;
PUT RES ;

RES.PC = 5  ;

PUT "ELIMINATE MANUFACTURING TARIFFS, EFFICIENCY WAGE MODEL "/ ;

PUT "PERCENT CHANGE IN FACTOR VARIABLES BY SECTOR"/;
put "", ;loop(i, put i.tl) ;
put / ;
loop(rf,
      put rf.tl;
      loop(i, put RFACTOR(rf,i));
      put /
    ) ; 
put // ;

PUT "PERCENT CHANGE IN QUANTITY VARIABLES BY SECTOR"/;
put "", ;loop(i, put i.tl) ;
put / ;
loop(rq,
      put rq.tl;
      loop(i, put RQUANT(rq,i));
      put /
    ) ; 
put // ;

PUT "EQUIVALENT VARIATION"; PUT ABAGG("ev") /;

